Re-exports
pub use loader::PluginHookLoadOutcome;pub use marketplace_upgrade::ConfiguredMarketplaceUpgradeError as PluginMarketplaceUpgradeError;pub use marketplace_upgrade::ConfiguredMarketplaceUpgradeOutcome as PluginMarketplaceUpgradeOutcome;pub use remote::RecommendedPlugin;pub use remote::RecommendedPluginsMode;
Modules
- installed_
marketplaces - loader
- manifest
- marketplace
- marketplace_
add - marketplace_
remove - marketplace_
upgrade - remote
- remote_
bundle - remote_
legacy - startup_
sync - store
- toggles
Structs
- Command
Migration Profile - Describes source-specific command migration behavior.
- Command
Rewrite Profile - Describes source-specific terms that should be rewritten in migrated command skills.
- Configured
Marketplace - Configured
Marketplace List Outcome - Configured
Marketplace Plugin - Effective
Plugins Change - Effective-plugin changes that downstream composition layers may act on.
- Executor
Plugin Provider - Resolves plugin packages through the filesystem owned by an execution environment.
- Plugin
Detail - Plugin
Install Outcome - Plugin
Install Request - Plugin
List Background Task Options - Plugin
Read Outcome - Plugin
Read Request - Plugins
Config Input - Plugins
Manager - Recommended
Plugin Candidates Input - Inputs used to select endpoint-backed plugin install candidates.
- Resolved
Executor Plugin - A resolved plugin paired with the concrete filesystem used to read it.
- Tool
Suggest Discoverable Plugin - Tool
Suggest Plugin Discovery Input
Enums
- Command
Description Mode - Controls how migrated commands obtain the description required by a Codex skill.
- Executor
Plugin Provider Error - Failure to resolve an environment-owned capability root as a plugin package.
- Plugin
Details Unavailable Reason - Plugin
Install Error - Plugin
Uninstall Error
Constants
Functions
- allowed_
configured_ marketplace_ names - apps_
route_ available - count_
missing_ commands_ with_ profile - import_
commands_ with_ profile - is_
openai_ curated_ marketplace_ name - missing_
command_ names_ with_ profile